pub enum FrameError {
NonFinite,
ZeroAxis,
DegenerateHint,
NotOrthonormal,
}Expand description
Why an origin and some directions are not a frame.
Variants
NonFinite
A coordinate is NaN or infinite.
ZeroAxis
The axis has zero length.
DegenerateHint
The x hint has no component perpendicular to the axis: it is zero
or exactly parallel to z.
NotOrthonormal
Axes given as a frame are not unit and mutually perpendicular to
rounding, or z ≠ x × y for a 3D frame.