orient2d

Function orient2d 

pub fn orient2d(a: Point2, b: Point2, c: Point2) -> Sign
The exact sign of twice the signed area of the triangle a b c: Positive when the points turn counter-clockwise (c is left of the directed line a → b), Negative when clockwise, Zero when collinear.