pub struct Isometry { /* private fields */ }Expand description
A rigid motion: a rotation followed by a translation, p ↦ R p + t.
Lengths and angles are preserved, so a Frame moved by one is still a
frame and geometry moved by one is the same geometry in another place
(docs/DATA-MODEL.md Conventions: a transform is a frame change).
use arris_math::{Isometry, Point3, Vec3, nalgebra::UnitQuaternion};
use core::f64::consts::FRAC_PI_2;
let quarter_turn = UnitQuaternion::from_axis_angle(&Vec3::z_axis(), FRAC_PI_2);
let m = Isometry::new(quarter_turn, Vec3::new(1.0, 0.0, 0.0));
let p = m.apply(Point3::new(1.0, 0.0, 0.0));
assert!((p - Point3::new(1.0, 1.0, 0.0)).norm() < 1e-15);
let back = m.inverse().apply(p);
assert!((back - Point3::new(1.0, 0.0, 0.0)).norm() < 1e-15);Implementations
Sourceimpl Isometry
impl Isometry
Sourcepub fn new(rotation: UnitQuaternion<f64>, translation: Vec3) -> Self
pub fn new(rotation: UnitQuaternion<f64>, translation: Vec3) -> Self
p ↦ rotation · p + translation.
Sourcepub fn from_translation(v: Vec3) -> Self
pub fn from_translation(v: Vec3) -> Self
A pure translation by v.
Sourcepub fn from_rotation(rotation: UnitQuaternion<f64>) -> Self
pub fn from_rotation(rotation: UnitQuaternion<f64>) -> Self
A pure rotation about the origin.
Sourcepub fn rotation(&self) -> UnitQuaternion<f64>
pub fn rotation(&self) -> UnitQuaternion<f64>
The rotation part.
Sourcepub fn translation(&self) -> Vec3
pub fn translation(&self) -> Vec3
The translation part: where the origin goes.
Sourcepub fn apply_vec(&self, v: Vec3) -> Vec3
pub fn apply_vec(&self, v: Vec3) -> Vec3
R v: a vector is a difference of points, so the translation does
not act on it.
Sourcepub fn apply_unit(&self, u: UnitVec3) -> UnitVec3
pub fn apply_unit(&self, u: UnitVec3) -> UnitVec3
R u, re-normalised so the result is unit to rounding.
Sourcepub fn apply_frame(&self, frame: &Frame) -> Frame
pub fn apply_frame(&self, frame: &Frame) -> Frame
The frame moved by this motion; the same as
Frame::transformed.